;/**
; *******************************************************************************
; * @file    startup_TMPM036.s
; * @brief   CMSIS Cortex-M0 Core Device Startup File for the
; *          TOSHIBA 'TMPM036' Device Series
; * @version V2.0.2.1 (Tentative)
; * @date    2014/11/19
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2014 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT0_IRQHandler           ; 0:	Interrupt Pin0(PB5)
                DCD     INT1_IRQHandler           ; 1:	Interrupt Pin1(PB6)
                DCD     INT2_IRQHandler           ; 2:	Interrupt Pin2(PB7)
                DCD     INT3_IRQHandler           ; 3:	Interrupt Pin3(PE7)
                DCD     INT4_IRQHandler           ; 4:	Interrupt Pin4(PE6)
                DCD     INT5_IRQHandler           ; 5:	Interrupt Pin5(PE5)
                DCD     INTRX01_IRQHandler        ; 6:	Serial reception (channel.0/1)
                DCD     INTT16A2_IRQHandler       ; 7:	16-bit TMR16A match detection (channel.2)
                DCD     INTTX01_IRQHandler        ; 8:	Serial transmission (channel.0/1)
                DCD     INTT16A3_IRQHandler       ; 9:	16-bit TMR16A match detection (channel.3)
                DCD     INTDMACB_IRQHandler       ; 10:	DMAC interrupt (unitB)
                DCD     INTI2C1_IRQHandler        ; 11:	Serial bus interface (channel.1)
                DCD     INTI2C0_IRQHandler        ; 12:	Serial bus interface (channel.0)
                DCD     INTDMACA_IRQHandler       ; 13:	DMAC interrupt (unitA)
                DCD     INTT16A0_IRQHandler       ; 14:	16-bit TMR16A match detection (channel.0)
                DCD     INTT16A1_IRQHandler       ; 15:	16-bit TMR16A match detection (channel.1)
                DCD     INTTMRB0_IRQHandler       ; 16:	16-bit TMRB interrupt(channel.0)
                DCD     INTTMRB1_IRQHandler       ; 17:	16-bit TMRB interrupt(channel.1)
                DCD     INTTMRB2_IRQHandler       ; 18:	16-bit TMRB interrupt(channel.2)
                DCD     INTTMRB3_IRQHandler       ; 19:	16-bit TMRB interrupt(channel.3)
                DCD     INTTMRB4_IRQHandler       ; 20:	16-bit TMRB interrupt(channel.4)
                DCD     INTTMRB5_IRQHandler       ; 21:	16-bit TMRB interrupt(channel.5)
                DCD     INTTMRB6_IRQHandler       ; 22:	16-bit TMRB interrupt(channel.6)
                DCD     INTTMRB7_IRQHandler       ; 23:	16-bit TMRB interrupt(channel.7)
                DCD     INTRX235_IRQHandler       ; 24:	Serial reception (channel.2/3/5)
                DCD     INTTMRB8_IRQHandler       ; 25:	16-bit TMRB interrupt(channel.8)
                DCD     INTTX235_IRQHandler       ; 26:	Serial transmission (channel.2/3/5)
                DCD     INTTMRB9_IRQHandler       ; 27:	16-bit TMRB interrupt(channel.9)
                DCD     INTRX4_IRQHandler         ; 28:	Serial reception (channel.4)
                DCD     INTTX4_IRQHandler         ; 29:	Serial transmission (channel.4)
                DCD     INTADC_IRQHandler         ; 30:	A/D conversion combined interrupt
                DCD     INTAD_IRQHandler          ; 31:	Normal A/D conversion completion interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INTRX01_IRQHandler        [WEAK]
                EXPORT  INTT16A2_IRQHandler       [WEAK]
                EXPORT  INTTX01_IRQHandler        [WEAK]
                EXPORT  INTT16A3_IRQHandler       [WEAK]
                EXPORT  INTDMACB_IRQHandler       [WEAK]
                EXPORT  INTI2C1_IRQHandler        [WEAK]
                EXPORT  INTI2C0_IRQHandler        [WEAK]
                EXPORT  INTDMACA_IRQHandler       [WEAK]
                EXPORT  INTT16A0_IRQHandler       [WEAK]
                EXPORT  INTT16A1_IRQHandler       [WEAK]
                EXPORT  INTTMRB0_IRQHandler       [WEAK]
                EXPORT  INTTMRB1_IRQHandler       [WEAK]
                EXPORT  INTTMRB2_IRQHandler       [WEAK]
                EXPORT  INTTMRB3_IRQHandler       [WEAK]
                EXPORT  INTTMRB4_IRQHandler       [WEAK]
                EXPORT  INTTMRB5_IRQHandler       [WEAK]
                EXPORT  INTTMRB6_IRQHandler       [WEAK]
                EXPORT  INTTMRB7_IRQHandler       [WEAK]
                EXPORT  INTRX235_IRQHandler       [WEAK]
                EXPORT  INTTMRB8_IRQHandler       [WEAK]
                EXPORT  INTTX235_IRQHandler       [WEAK]
                EXPORT  INTTMRB9_IRQHandler       [WEAK]
                EXPORT  INTRX4_IRQHandler         [WEAK]
                EXPORT  INTTX4_IRQHandler         [WEAK]
                EXPORT  INTADC_IRQHandler         [WEAK]
                EXPORT  INTAD_IRQHandler          [WEAK]

INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INT5_IRQHandler
INTRX01_IRQHandler
INTT16A2_IRQHandler
INTTX01_IRQHandler
INTT16A3_IRQHandler
INTDMACB_IRQHandler
INTI2C1_IRQHandler
INTI2C0_IRQHandler
INTDMACA_IRQHandler
INTT16A0_IRQHandler
INTT16A1_IRQHandler
INTTMRB0_IRQHandler
INTTMRB1_IRQHandler
INTTMRB2_IRQHandler
INTTMRB3_IRQHandler
INTTMRB4_IRQHandler
INTTMRB5_IRQHandler
INTTMRB6_IRQHandler
INTTMRB7_IRQHandler
INTRX235_IRQHandler
INTTMRB8_IRQHandler
INTTX235_IRQHandler
INTTMRB9_IRQHandler
INTRX4_IRQHandler
INTTX4_IRQHandler
INTADC_IRQHandler
INTAD_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

