;/**
; *******************************************************************************
; * @file    startup_TMPM037.s
; * @brief   CMSIS Cortex-M0 Core Device Startup File for the
; *          TOSHIBA 'TMPM037' Device Series
; * @version V2.0.2.1 (Tentative)
; * @date    2014/02/07
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
; * CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR,
; * STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED WARRANTIES OF MERCHANTABILITY,
; * SATISFACTORY QUALITY, NON INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
; * 
; * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA CORPORATION
; * RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS TO THE SOURCE CODE IN LATER
; * REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR CHANGES IN THE DOCUMENTATION OR
; * THE PRODUCTS OR TECHNOLOGIES DESCRIBED THEREIN AT ANY TIME.
; * 
; * TOSHIBA CORPORATION SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT OR
; * CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE OF THE SOURCE CODE OR
; * ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST REVENUES, DATA OR
; * PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR CONSEQUENTIAL NATURE, PUNITIVE
; * DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS ARISING OUT OF OR IN CONNECTION
; * WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN IF ADVISED OF THE POSSIBILITY OR
; * PROBABILITY OF SUCH DAMAGES AND WHETHER A CLAIM FOR SUCH DAMAGE IS BASED UPON
; * WARRANTY, CONTRACT, TORT, NEGLIGENCE OR OTHERWISE.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2014 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT0_IRQHandler           ; 0:	Interrupt Pin0(PB5)
                DCD     INT1_IRQHandler           ; 1:	Interrupt Pin1(PB6)
                DCD     INT2_IRQHandler           ; 2:	Interrupt Pin2(PB7)
                DCD     INT3_IRQHandler           ; 3:	Interrupt Pin3(PE7)
                DCD     INT4_IRQHandler           ; 4:	Interrupt Pin4(PE6)
                DCD     INT5_IRQHandler           ; 5:	Interrupt Pin5(PE5)
                DCD     INTRX0_IRQHandler         ; 6:	Serial reception (channel.0)
                DCD     INTTX0_IRQHandler         ; 7:	Serial transmission (channel.0)
                DCD     INTRX1_IRQHandler         ; 8:	Serial reception (channel.1)
                DCD     INTTX1_IRQHandler         ; 9:	Serial transmission (channel.1)
                DCD     0                         ; 10:	Reserved
                DCD     0                         ; 11:	Reserved
                DCD     INTI2C0_IRQHandler        ; 12:	Serial bus interface
                DCD     INTDMAC_IRQHandler        ; 13:	DMAC interrupt
                DCD     INTT16A0_IRQHandler       ; 14:	16-bit TMR16A match detection (channel.0)
                DCD     INTT16A1_IRQHandler       ; 15:	16-bit TMR16A match detection (channel.1)
                DCD     INTTMRB0_IRQHandler       ; 16:	16-bit TMRB interrupt(channel.0)
                DCD     INTTMRB1_IRQHandler       ; 17:	16-bit TMRB interrupt(channel.1)
                DCD     INTTMRB2_IRQHandler       ; 18:	16-bit TMRB interrupt(channel.2)
                DCD     INTTMRB3_IRQHandler       ; 19:	16-bit TMRB interrupt(channel.3)
                DCD     INTTMRB4_IRQHandler       ; 20:	16-bit TMRB interrupt(channel.4)
                DCD     INTTMRB5_IRQHandler       ; 21:	16-bit TMRB interrupt(channel.5)
                DCD     INTTMRB6_IRQHandler       ; 22:	16-bit TMRB interrupt(channel.6)
                DCD     INTTMRB7_IRQHandler       ; 23:	16-bit TMRB interrupt(channel.7)
                DCD     INTRX2_IRQHandler         ; 24:	Serial reception (channel.2)
                DCD     INTTX2_IRQHandler         ; 25:	Serial transmission (channel.2)
                DCD     INTRX3_IRQHandler         ; 26:	Serial reception (channel.3)
                DCD     INTTX3_IRQHandler         ; 27:	Serial transmission (channel.3)
                DCD     INTRX4_IRQHandler         ; 28:	Serial reception (channel.4)
                DCD     INTTX4_IRQHandler         ; 29:	Serial transmission (channel.4)
                DCD     INTADC_IRQHandler         ; 30:	A/D conversion combined interrupt
                DCD     INTAD_IRQHandler          ; 31:	Normal A/D conversion completion interrupt



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INTRX0_IRQHandler         [WEAK]
                EXPORT  INTTX0_IRQHandler         [WEAK]
                EXPORT  INTRX1_IRQHandler         [WEAK]
                EXPORT  INTTX1_IRQHandler         [WEAK]
                EXPORT  INTI2C0_IRQHandler        [WEAK]
                EXPORT  INTDMAC_IRQHandler        [WEAK]
                EXPORT  INTT16A0_IRQHandler       [WEAK]
                EXPORT  INTT16A1_IRQHandler       [WEAK]
                EXPORT  INTTMRB0_IRQHandler       [WEAK]
                EXPORT  INTTMRB1_IRQHandler       [WEAK]
                EXPORT  INTTMRB2_IRQHandler       [WEAK]
                EXPORT  INTTMRB3_IRQHandler       [WEAK]
                EXPORT  INTTMRB4_IRQHandler       [WEAK]
                EXPORT  INTTMRB5_IRQHandler       [WEAK]
                EXPORT  INTTMRB6_IRQHandler       [WEAK]
                EXPORT  INTTMRB7_IRQHandler       [WEAK]
                EXPORT  INTRX2_IRQHandler         [WEAK]
                EXPORT  INTTX2_IRQHandler         [WEAK]
                EXPORT  INTRX3_IRQHandler         [WEAK]
                EXPORT  INTTX3_IRQHandler         [WEAK]
                EXPORT  INTRX4_IRQHandler         [WEAK]
                EXPORT  INTTX4_IRQHandler         [WEAK]
                EXPORT  INTADC_IRQHandler         [WEAK]
                EXPORT  INTAD_IRQHandler          [WEAK]

INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INT5_IRQHandler
INTRX0_IRQHandler
INTTX0_IRQHandler
INTRX1_IRQHandler
INTTX1_IRQHandler
INTI2C0_IRQHandler
INTDMAC_IRQHandler
INTT16A0_IRQHandler
INTT16A1_IRQHandler
INTTMRB0_IRQHandler
INTTMRB1_IRQHandler
INTTMRB2_IRQHandler
INTTMRB3_IRQHandler
INTTMRB4_IRQHandler
INTTMRB5_IRQHandler
INTTMRB6_IRQHandler
INTTMRB7_IRQHandler
INTRX2_IRQHandler
INTTX2_IRQHandler
INTRX3_IRQHandler
INTTX3_IRQHandler
INTRX4_IRQHandler
INTTX4_IRQHandler
INTADC_IRQHandler
INTAD_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

