;/**
; *******************************************************************************
; * @file    startup_TMPM073.s
; * @brief   CMSIS Cortex-M0 Core Device Startup File for the
; *          TOSHIBA 'TMPM073' Device Series
; * @version V2.0.2.4 (Tentative)
; * @date    2014/12/22
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
; * 
; * (C)Copyright TOSHIBA CORPORATION 2014 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     0                         ; 0:	Reserved
                DCD     INT4_IRQHandler           ; 1:	Interrupt pin (PA2/TB1IN/INT4)
                DCD     INT5_IRQHandler           ; 2:	Interrupt pin (PE4/TB2IN/INT5)
                DCD     INT6_IRQHandler           ; 3:	Interrupt pin (PE6/TB3IN/INT6)
                DCD     INT7_IRQHandler           ; 4:	Interrupt pin (PE7/TB3OUT/INT7)
                DCD     0                         ; 5:	Reserved
                DCD     INTC_IRQHandler           ; 6:	Interrupt pin (PJ6/AINB9/INTC)
                DCD     INTD_IRQHandler           ; 7:	Interrupt pin (PJ7/AINB10/INTD)
                DCD     INTE_IRQHandler           ; 8:	Interrupt pin (PK0/AINB11/INTE)
                DCD     INTF_IRQHandler           ; 9:	Interrupt pin (PK1/AINB12/INTF)
                DCD     INTENC1_IRQHandler        ; 10:	Encoder input interrupt 1
                DCD     INTVCNB_IRQHandler        ; 11:	Vector Engine interrupt B
                DCD     INTPMD1S_IRQHandler       ; 12:	PMD1 request / EMG / OVV interrupt
                DCD     INTSIO0_IRQHandler        ; 13:	Serial reception transmission (channel0)
                DCD     INTSIO1_IRQHandler        ; 14:	Serial reception transmission (channel1) / Serial bus interface (channel0)
                DCD     0                         ; 15:	Reserved
                DCD     INTSIO3_IRQHandler        ; 16:	Serial reception transmission (channel3)
                DCD     INTADBPDB_IRQHandler      ; 17:	ADCB conversion triggered by PMD1 is finished
                DCD     INTADBTS_IRQHandler       ; 18:	ADCB conversion started by software / triggered by timer is finished
                DCD     INTADBCP0_IRQHandler      ; 19:	ADCB conversion monitoring function 0 interrupt
                DCD     INTADBCP1_IRQHandler      ; 20:	ADCB conversion monitoring function 1 interrupt
                DCD     INTTMRB0_IRQHandler       ; 21:	16bit TMRB0 compare match detection / Over flow / input capture0
                DCD     INTTMRB1_IRQHandler       ; 22:	16bit TMRB1 compare match detection / Over flow / input capture0
                DCD     INTTMRB2_IRQHandler       ; 23:	16bit TMRB2 compare match detection / Over flow / input capture0
                DCD     INTTMRB3_IRQHandler       ; 24:	16bit TMRB3 compare match detection / Over flow / input capture0
                DCD     INTTMRB4_IRQHandler       ; 25:	16bit TMRB4 compare match detection / Over flow / input capture0
                DCD     INTTMRB5_IRQHandler       ; 26:	16bit TMRB5 compare match detection / Over flow
                DCD     INTTMRB6_IRQHandler       ; 27:	16bit TMRB6 compare match detection / Over flow / input capture0
                DCD     INTTMRB7_IRQHandler       ; 28:	16bit TMRB7 compare match detection / Over flow / input capture0
                DCD     INTTMRB8_IRQHandler       ; 29:	16bit TMRB8 compare match detection / Over flow
                DCD     INTTMRB9_IRQHandler       ; 30:	16bit TMRB9 compare match detection / Over flow
                DCD     INTDMACAS_IRQHandler      ; 31:	DMA end of transfer / transfer error



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INT6_IRQHandler           [WEAK]
                EXPORT  INT7_IRQHandler           [WEAK]
                EXPORT  INTC_IRQHandler           [WEAK]
                EXPORT  INTD_IRQHandler           [WEAK]
                EXPORT  INTE_IRQHandler           [WEAK]
                EXPORT  INTF_IRQHandler           [WEAK]
                EXPORT  INTENC1_IRQHandler        [WEAK]
                EXPORT  INTVCNB_IRQHandler        [WEAK]
                EXPORT  INTPMD1S_IRQHandler       [WEAK]
                EXPORT  INTSIO0_IRQHandler        [WEAK]
                EXPORT  INTSIO1_IRQHandler        [WEAK]
                EXPORT  INTSIO3_IRQHandler        [WEAK]
                EXPORT  INTADBPDB_IRQHandler      [WEAK]
                EXPORT  INTADBTS_IRQHandler       [WEAK]
                EXPORT  INTADBCP0_IRQHandler      [WEAK]
                EXPORT  INTADBCP1_IRQHandler      [WEAK]
                EXPORT  INTTMRB0_IRQHandler       [WEAK]
                EXPORT  INTTMRB1_IRQHandler       [WEAK]
                EXPORT  INTTMRB2_IRQHandler       [WEAK]
                EXPORT  INTTMRB3_IRQHandler       [WEAK]
                EXPORT  INTTMRB4_IRQHandler       [WEAK]
                EXPORT  INTTMRB5_IRQHandler       [WEAK]
                EXPORT  INTTMRB6_IRQHandler       [WEAK]
                EXPORT  INTTMRB7_IRQHandler       [WEAK]
                EXPORT  INTTMRB8_IRQHandler       [WEAK]
                EXPORT  INTTMRB9_IRQHandler       [WEAK]
                EXPORT  INTDMACAS_IRQHandler      [WEAK]

INT4_IRQHandler
INT5_IRQHandler
INT6_IRQHandler
INT7_IRQHandler
INTC_IRQHandler
INTD_IRQHandler
INTE_IRQHandler
INTF_IRQHandler
INTENC1_IRQHandler
INTVCNB_IRQHandler
INTPMD1S_IRQHandler
INTSIO0_IRQHandler
INTSIO1_IRQHandler
INTSIO3_IRQHandler
INTADBPDB_IRQHandler
INTADBTS_IRQHandler
INTADBCP0_IRQHandler
INTADBCP1_IRQHandler
INTTMRB0_IRQHandler
INTTMRB1_IRQHandler
INTTMRB2_IRQHandler
INTTMRB3_IRQHandler
INTTMRB4_IRQHandler
INTTMRB5_IRQHandler
INTTMRB6_IRQHandler
INTTMRB7_IRQHandler
INTTMRB8_IRQHandler
INTTMRB9_IRQHandler
INTDMACAS_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

